#' Derive PAI from PASTIS
#' 
#' Derive PAI from PASTIS readings
#' 
#' @description Assuming exponential extinction.
#' 
#' @param obs Observation sensor reading.
#' @param ref Reference sensor reading.
#' 
#' @return PAI (numeric)
#' 
#' @export
#' 
#' @author Benjamin Brede
#' 
#' @references Lecerf, R., Baret, F., Hanocq, J., Marloie, O., Rautiainen, M., Mottus, M., … Stenberg, P. (2010). PASTIS 57: Autonomous light sensors for PAI continuous monitoring. Principles, calibration and application to vegetation phenology. In AGU Fall Meeting Abstracts 12/2010.

PAI <- function(obs, ref) {
  x <- -1.075 * log(obs / ref)
  ifelse(is.infinite(x), NA, x)
}


