#' Derive PAI from PASTIS, correct for clumping with Lang & Yuequin (1986) method
#' 
#' @description Use clumping correction with logarithmic means.
#' 
#' @param obs Observation sensor reading.
#' @param ref Reference sensor reading.
#' 
#' @return PAI (numeric[1])
#' 
#' @export
#' 
#' @author Benjamin Brede
#' 
#' @references Lang & Yuequin (1986): Estimating Leaf Area Index from Transmission of Direct Sunlight in Discontinuous Canopies

PAI_LX <- function(obs, ref) {
  tau <- obs / ref
  # clumping index 
  ci <- log(mean(tau)) / mean(log(tau))
  PAI(mean(tau), 1) / ci
}

