#' Eval readings of one PASTIS device
#' 
#' Eval readings of one PASTIS device
#' 
#' @description Data reads must have same reading intervals and readings times (made in the same minute). Output time in UTC.
#' 
#' @param obs Observations sensor readings (as output of \code{\link{readPASTIS}}).
#' @param ref Reference sensor readings (as output of \code{\link{readPASTIS}}).
#' 
#' @return Data.frame with PAI estimates at PASTIS native temporal resolution.
#' 
#' @export
#' 
#' @import lubridate
#'
#' @author Benjamin Brede


evalPASTISsimple <- function(obs, ref, tindex, sensors = c('NW', 'SE', 'W', 'E', 'SW', 'NE')) {
  
  # DateTime in sec since 1970 for merge with other data later
  obs$Tindex <- tindex(obs)
  ref$Tindex <- tindex(ref)
  
  # merge tables
  df <- merge(obs, ref, by = 'Tindex', suffixes = c('_obs', '_ref'))
  
  res <- do.call(cbind, lapply(sensors, function(sensor) {
    ob <- df[, paste0(sensor, '_obs')]
    re <- df[, paste0(sensor, '_ref')]
    
    r <- data.frame(PAI(ob, re))
    names(r) <- paste0('PAI_', sensor)
    r
  }))   
  
  cbind(df, res)
}
