#' Calculate SZA and SAA
#' 
#' @import insol
#' @import lubridate
#'
#' @author Benjamin Brede

require(insol)
require(lubridate)

solarAngles <- function(t, lat = 52.25, lon = 5.7) {
  
  if (length(lat) > 1 | length(lon) > 1)
    warning('No vectorisation for lat long provided! First values will be used!')
  
  as.data.frame(sunpos(sunvector(JD(with_tz(t, 'UTC')), latitude = lat, longitude = lon, timezone = 0)))
}

solarZenith <- function(t, lat = 52.25, lon = 5.7) {
  solarAngles(t, lat, lon)$zenith
}

solarAzimuth <- function(t, lat = 52.25, lon = 5.7) {
  solarAngles(t, lat, lon)$azimuth
}