#' Summarise PASTIS to daily values
#' 
#' @param matched Matched PASTIS readings
#' 
#' @return Data.frame with PAI estimates (daily).
#' 
#' @export
#' 
#' @import lubridate
#' @import dplyr
#'
#' @author Benjamin Brede

require(lubridate)
require(dplyr)

summarisePASTIS_LX <- function(matched, maxSZA = 80) {
  
  matched %>%
    mutate(DOY = doy(DateTime),
           SZA = solarZenith(DateTime)) %>%
    filter(SZA < maxSZA) %>%
    group_by(Sensor, DOY) %>%
    filter(!is.na(Obs), !is.na(Ref)) %>%
    summarise(Pgap = mean(Obs / Ref),
              N = n()) %>%
    ungroup() %>%
    group_by(DOY) %>%
    summarise(CI = log(mean(Pgap)) / mean(log(Pgap)),
              PAI = ifelse(CI == 0, PAI(mean(Pgap), 1), PAI(mean(Pgap), 1) / CI),
              DateTime = parse_doy(DOY[1])) %>%
    ungroup()
}
